<?php

namespace Drupal\evac\Utility;

use Drupal\Component\Utility\EmailValidatorInterface;
use Drupal\evac\ValidatorLoggingTrait;
use Egulias\EmailValidator\EmailValidator as EmailValidatorUtility;
use Egulias\EmailValidator\Validation\EmailValidation;
use Egulias\EmailValidator\Validation\DNSCheckValidation;

/**
 * Validates email addresses.
 */
class DNSCheckValidator extends EmailValidatorUtility implements EmailValidatorInterface {

  use ValidatorLoggingTrait;

  /**
   * Validates an email address.
   *
   * @param string $email
   *   A string containing an email address.
   * @param \Egulias\EmailValidator\Validation\EmailValidation|null $email_validation
   *   This argument is ignored. If it is supplied an error will be triggered.
   *   See https://www.drupal.org/node/2997196.
   *
   * @return bool
   *   TRUE if the address is valid.
   */
  public function isValid($email, EmailValidation $email_validation = NULL): bool {
    if ($email_validation) {
      throw new \BadMethodCallException('Calling \Drupal\evac\Utility\DNSCheckValidator::isValid() with the second argument is not supported. See https://www.drupal.org/node/2997196');
    }

    $is_valid = parent::isValid($email, (new DNSCheckValidation()));
    if (!$is_valid) {
      $this->log($email, $this);
    }

    return $is_valid;
  }

}
